

set -ex



test -d $PREFIX/include/qt6/QtShaderTools
test -f $PREFIX/lib/libQt6ShaderTools${SHLIB_EXT}
LD_LIBRARY_PATH="${PREFIX}/${HOST}/sysroot/usr/lib64:${PREFIX}/${HOST}/sysroot/usr/lib:${LD_LIBRARY_PATH}" ${PREFIX}/lib/qt6/bin/qsb --version
exit 0
